ConsistentHashOpts

Struct ConsistentHashOpts 

pub struct ConsistentHashOpts {
    pub header: Option<String>,
}
Options for the consistent_hash load-balancing strategy.

Fields

header: Option<String>

Name of the request header to use as the hash key.

Falls back to the request URI path when the header is absent or when this field is None.